@@ -13,10 +13,12 @@ our @EXPORT_OK = qw(
 
 sub test_db_or_skip {
   my $cfg = shift;
+
   # source:
   # https://metacpan.org/pod/distribution/MongoDB/lib/MongoDB/Upgrading.pod
-  plan skip_all => 'no mongod' unless eval {
-    MongoDB->connect->db($cfg->{db})->run_command([ ismaster => 1 ])
-  }
+  plan skip_all => 'no mongod'
+    unless eval {
+    MongoDB->connect->db( $cfg->{db} )->run_command( [ ismaster => 1 ] );
+    };
 }
 
